remarkable-tweak
================

Tweak tool for the reMarkable paper tablet. Lets you organize your
templates with no fuss.

*This package is non-functional for end-users at the moment*

*NOTE*: This is currently in a very early stage, and not ready for
release. Please contact if interested in contributing, though.
